@@ -2,6 +2,7 @@ import configparser
 import logging
 import sys
 
+import discord
 from discord.ext import commands
 
 from remote_mole.setup.entrypoint import CONFIG_PATH
@@ -11,7 +12,7 @@ from remote_mole._internal.services.ngrok import (
     Tunnel,
     TunnelAlredyOpenError,
 )
-
+from remote_mole._internal.services.lxi import LXIDevice
 
 logging.basicConfig(stream=sys.stdout, level=logging.INFO)
 log = logging.getLogger('remote_mole')
@@ -57,6 +58,7 @@ async def on_ready():
     set_region(region)
     log.info(f'Ngrok region set to {region}.')
     bot.tunnels = {}
+    bot.lxi_dev = None
 
 
 def get_connection_instructions(tunnel, tunnel_type):
@@ -173,6 +175,63 @@ async def jupyter_advice(ctx):
     )
 
 
+@bot.command()
+async def lxi_connect(ctx, device_name):
+    """Connects to a LXI remote instrument
+
+    Usage:
+    lxi_connect device_name
+    """
+    await ctx.send(
+        'Connecting... this can take a while.'
+    )
+    try:
+        bot.lxi_dev = LXIDevice(device_name)
+        await ctx.send(
+            f"{bot.lxi_dev.name} connected!."
+        )
+    except RuntimeError:
+        await ctx.send(
+            f"No {device_name} found on the network."
+        )
+
+
+@bot.command()
+async def lxi_screenshot(ctx):
+    """Takes a screenshot of LXI device
+
+    Usage:
+    lxi_screenshot
+    """
+    if bot.lxi_dev is not None:
+        screenshot_path = bot.lxi_dev.capture_screenshot()
+        await ctx.send(
+            file=discord.File(screenshot_path),
+        )
+    else:
+        await ctx.send(
+            "First, connect to a lxi device with lxi_connect."
+        )
+
+
+@bot.command()
+async def lxi_command(ctx, command):
+    """Send commands to LXI remote instrument
+
+    Usage:
+    lxi_command command
+    """
+    response = bot.lxi_dev.send_command(command)
+    if response == "":
+        await ctx.send(
+            "Sent!"
+        )
+    else:
+        await ctx.send(
+            f'{response}',
+        )
+
+
 @bot.event
 async def on_command_error(ctx, error):
     if isinstance(error, commands.errors.CommandNotFound):
